'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

exports.default = function (_ref) {
  var t = _ref.types;


  var makeObjectProperty = function makeObjectProperty(name, value) {
    var position = arguments.length <= 2 || arguments[2] === undefined ? '' : arguments[2];

    return t.ObjectProperty(t.Identifier('' + name + position), t.NumericLiteral(value));
  };

  var postions = ['Top', 'Right', 'Bottom', 'Left'];
  var supportedProperties = ['margin', 'padding'];

  return {
    visitor: {
      ObjectProperty: function ObjectProperty(path) {
        var _path$node = path.node;
        var key = _path$node.key;
        var value = _path$node.value;

        if (supportedProperties.indexOf(key.name) > -1 && value.type === 'ArrayExpression') {
          (function () {
            // StyleSheet check, don't know if this one is efficient enough
            var callee = undefined;
            path.find(function (path) {
              if (path.isCallExpression()) {
                callee = path.node.callee;
              };
              // we've got a callee! no need to continue
              if (callee) return;
            });

            if (callee && callee.object && callee.object.name === 'StyleSheet') {
              switch (value.elements.length) {
                case 1:
                  path.replaceWith(makeObjectProperty(key.name, value.elements[0].value));
                  break;
                default:
                  var elements = postions.map(function (position, idx) {
                    var element = value.elements[idx] || value.elements[idx % 2];
                    return makeObjectProperty(key.name, element.value, position);
                  });
                  path.replaceWithMultiple(elements);
              }
            }
          })();
        }
      }
    }
  };
};